#!/bin/bash
#
# Copyright 2014 by Thomas Jampen
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.



KINET_DIR="/usr/share/kinet"
GKEYRING="/usr/bin/gkeyring"
KINET_KEY="KINET-Account"
DOMAIN="kinet"



# includes
. ${KINET_DIR}/kinet-misc.sh



keyring-ask-for-and-store-kinet-account() {
	if ! $(is-binary-installed "/usr/bin/yad")
	then
		return 1
	fi

	# ask for kinet account
	TITLE="KINET-Benutzerkonto"
	TOKENS=$(yad --form --field="Benutzername" --field="Passwort:H" --title="${TITLE}")
	RETVAL=${?}

	# exit if user aborted the login dialog
	if [ ${RETVAL} -ne 0 ]
	then
		return 1
	fi

	USERNAME=$(echo ${TOKENS} | sed -e 's/|.*$//')
	PASSWORD=$(echo ${TOKENS#*|} | sed -e 's/|//')

	keyring-store-kinet-account "${DOMAIN}" "${USERNAME}" "${PASSWORD}"
}



keyring-store-kinet-account() {
	# parameters
	local DOMAIN="${1}"
	local USERNAME="${2}"
	local PASSWODR="${3}"

	# abort if gkeyring is missing
	if ! $(is-binary-installed ${GKEYRING})
	then
		return 1
	fi

	# add account to the keyring
	gkeyring --set --name "${KINET_KEY}" -p username=${USERNAME},domain=${DOMAIN} --password="${PASSWORD}"
	return ${?}
}



keyring-retrieve-kinet-account() {
	if ! $(is-binary-installed ${GKEYRING})
	then
		return 1
	fi

	# retrieve gnome keyring data
	local KEYS="domain,username,secret"
	local USER_DATA=$(${GKEYRING} --name "${KINET_KEY}" --output "${KEYS}")
	local REGEXP="^[a-zA-Z]+[[:space:]][a-zA-Z0-9.]+[[:space:]].+$"

	# is the user account stored in gnome-keyring
	if [[ ${USER_DATA} =~ ${REGEXP} ]]
	then
		echo ${USER_DATA}
		return 0
	else
		echo "No user data found in gnome keyring."
		return 1
	fi
}



keyring-has-kinet-account() {
	if ! $(is-binary-installed ${GKEYRING})
	then
		return 1
	fi

	# retrieve gnome keyring data
	${GKEYRING} --name "${KINET_KEY}" --output "id"

	if [ ${?} -eq 0 ]
	then
		return 0
	else
		return 1
	fi
}



keyring-get-username() {
	local USER_DATA="$(keyring-retrieve-kinet-account)"
	local USERNAME="$(echo ${USER_DATA} | awk '{print $2}')"

	if [ -n "${USERNAME}" ]
	then
		echo "${USERNAME}"
		return 0
	else
		echo "Username not found."
		return 1
	fi
}



keyring-get-password() {
	local USER_DATA="$(keyring-retrieve-kinet-account)"
	local PASSWORD="$(echo ${USER_DATA} | awk '{print $3}')"

	if [ -n "${PASSWORD}" ]
	then
		echo "${PASSWORD}"
		return 0
	else
		echo "Password not found."
		return 1
	fi
}



keyring-get-domain() {
	local USER_DATA="$(keyring-retrieve-kinet-account)"
	local DOMAIN="$(echo ${USER_DATA} | awk '{print $1}')"

	if [ -n "${DOMAIN}" ]
	then
		echo "${DOMAIN}"
		return 0
	else
		echo "Domain not found."
		return 1
	fi
}



keyring-is-student() {
	local USERNAME="$(keyring-get-username)"
	local REGEXP="^[a-zA-Z0-9]+\.[a-zA-Z0-9]+$"

	# is the user a student (e.g. does the username contain a dot)
	if [[ ${USERNAME} =~ ${REGEXP} ]]
	then
		return 0
	else
		return 1
	fi
}
